@@ -1,5 +1,5 @@
 package Form::Factory::Feature::Control::MatchAvailableChoices;
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 
 use Moose;
@@ -17,7 +17,7 @@ Form::Factory::Feature::Control::MatchAvailableChoices - Check for choice availa
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -51,8 +51,7 @@ sub check_control {
     die "the match_available_options feature only works for controls that have available choices, not $control"
         unless $control->does('Form::Factory::Control::Role::AvailableChoices');
 
-    return if $control->does('Form::Factory::Control::Role::ListValue');
-    return if $control->does('Form::Factory::Control::Role::ScalarValue');
+    return if $control->does('Form::Factory::Control::Role::Value');
 
     die "the match_available_feature does not know hwo to check the value of $control";
 }
@@ -70,23 +69,29 @@ sub check {
     my %available_values = map { $_->value => 1 } 
         @{ $self->control->available_choices };
 
-    # Deal with scalar valued controls
-    if ($control->does('Form::Factory::Control::Role::ScalarValue')) {
-        my $value = $control->current_value;
-        $self->control_error('the given value for %s is not one of the available choices')
-            unless $available_values{ $value };
-    }
-
     # Deal with list valued controls
-    else {
+    if ($control->does('Form::Factory::Control::Role::ListValue')) {
         my $values = $control->current_values;
         VALUE: for my $value (@$values) {
             unless ($available_values{ $value }) {
                 $self->control_error('one of the values given for %s is not in the list of available choices');
+                $self->result->is_valid(0);
                 last VALUE;
             }
         }
     }
+
+    # Deal with scalar valued controls
+    else {
+        my $value = $control->current_value;
+        unless ($available_values{ $value }) {
+            $self->control_error('the given value for %s is not one of the available choices');
+            $self->is_valid(0);
+        }
+    }
+
+    # If not already validated
+    $self->result->is_valid(1) unless $self->result->is_validated;
 }
 
 =head1 AUTHOR
