@@ -1,5 +1,5 @@
 package Form::Factory::Processor;
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 
 use Moose;
@@ -13,7 +13,7 @@ use Form::Factory::Processor::DeferredValue;
 Moose::Exporter->setup_import_methods(
     as_is     => [ qw( deferred_value ) ],
     with_meta => [ qw(
-        has_control
+        has_control use_feature
         has_cleaner has_checker has_pre_processor has_post_processor
     ) ],
     also      => 'Moose',
@@ -25,12 +25,12 @@ Form::Factory::Processor - Moos-ish helper for action classes
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
   package MyApp::Action::Foo;
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 
   use Form::Factory::Processor;
@@ -61,8 +61,10 @@ our $VERSION = '0.010';
       my $self = shift;
       my $value = $self->controls->{name}->current_value;
 
-      $self->error('i do not like names start with "R," get a new name')
-          if $value =~ /^R/i;
+      if ($value =~ /^R/i) {
+          $self->error('i do not like names start with "R," get a new name');
+          $self->result->is_valid(0);
+      }
   };
 
   has_pre_processor log_start => sub {
@@ -181,6 +183,30 @@ sub has_control {
     $meta->add_attribute( $name => $args );
 }
 
+=head2 use_feature
+
+This function is used to make an action use a particular form feature. It's usage is as follows:
+
+  use_feature $name => \%options;
+
+The C<%options> are optional. So,
+
+  use_feature $name;
+
+will also work if you do not need to pass any features.
+
+The C<$name> is a short name for the feature class. For example, the name "require_none_or_all" will load the feature defined in L<Form::Factory::Feature::RequireNoneOrAll>.
+
+=cut
+
+sub use_feature {
+    my $meta = shift;
+    my $name = shift;
+    my $args = @_ == 1 ? shift : { @_ };
+
+    $meta->features->{$name} = $args;
+}
+
 =head2 deferred_value
 
   has_control publish_on => (
@@ -231,16 +257,16 @@ Adds some code called during the post-process phase.
 
 =cut
 
-sub _add_feature {
+sub _add_function {
     my ($type, $meta, $name, $code) = @_;
     die "bad code given for $type $name" unless defined $code;
     $meta->features->{functional}{$type . '_code'}{$name} = $code;
 }
 
-sub has_cleaner        { _add_feature('cleaner', @_) }
-sub has_checker        { _add_feature('checker', @_) }
-sub has_pre_processor  { _add_feature('pre_processor', @_) }
-sub has_post_processor { _add_feature('post_processor', @_) }
+sub has_cleaner        { _add_function('cleaner', @_) }
+sub has_checker        { _add_function('checker', @_) }
+sub has_pre_processor  { _add_function('pre_processor', @_) }
+sub has_post_processor { _add_function('post_processor', @_) }
 
 =head1 SEE ALSO
 
